"use strict";
//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCurrentContext = void 0;
var react_1 = require("react");
var auth_call_api_1 = require("./auth-call-api");
var lodash_1 = require("lodash");
var primeobjects_helper_util_1 = require("primeobjects-helper-util");
var primeobjects_ui_web_store_1 = require("primeobjects-ui-web-store");
var auth_cognito_1 = require("./auth-cognito");
var util_1 = require("../util");
var core_1 = require("primeobjects-helper-util/build/cjs/core");
var primeobjects_helper_ui_1 = require("primeobjects-helper-ui");
var useCurrentContext = function (solution, settings) {
    var _a = (0, react_1.useState)(undefined), context = _a[0], setContext = _a[1];
    var loading = (0, react_1.useRef)("");
    var refresh = settings === null || settings === void 0 ? void 0 : settings.refresh;
    var contextStore = (0, primeobjects_ui_web_store_1.useContextStore)();
    var SSR = (0, primeobjects_helper_util_1.isSSR)();
    if (!(solution === null || solution === void 0 ? void 0 : solution.id)) {
        console.error("There's no solution provided for context.");
    }
    var onError = function (error) {
        console.error(error);
        setContext(undefined);
        if (settings === null || settings === void 0 ? void 0 : settings.onError) {
            settings === null || settings === void 0 ? void 0 : settings.onError(error);
        }
        else {
            if (settings &&
                settings.signInUrl &&
                (0, primeobjects_helper_util_1.isNonEmptyString)(settings === null || settings === void 0 ? void 0 : settings.signInUrl)) {
                (0, primeobjects_helper_util_1.getWindow)().location.replace(settings.signInUrl);
            }
        }
    };
    var processResult = function (result, settings) {
        var _a, _b;
        var settingContext = (0, primeobjects_helper_util_1.isObject)(settings === null || settings === void 0 ? void 0 : settings.context)
            ? (0, lodash_1.cloneDeep)(settings === null || settings === void 0 ? void 0 : settings.context)
            : {};
        var currentContext = result.context;
        if ((0, primeobjects_helper_util_1.isObject)(settingContext.recordByMembership)) {
            currentContext.recordByMembership = __assign(__assign({}, ((0, primeobjects_helper_util_1.isObject)(currentContext.recordByMembership)
                ? currentContext.recordByMembership
                : {})), settingContext.recordByMembership);
        }
        if ((0, primeobjects_helper_util_1.isObject)(settingContext.organization)) {
            currentContext.organization = __assign(__assign({}, ((0, primeobjects_helper_util_1.isObject)(currentContext.organization)
                ? currentContext.organization
                : {})), settingContext.organization);
        }
        if ((_b = (_a = currentContext.organization) === null || _a === void 0 ? void 0 : _a.color) === null || _b === void 0 ? void 0 : _b.name) {
            (0, primeobjects_helper_util_1.setColorTheme)(currentContext.organization.color.name, currentContext.organization.color);
            (0, primeobjects_helper_ui_1.setPrimaryColor)(currentContext.organization.color);
        }
        if ((0, primeobjects_helper_util_1.isObject)(settingContext.user)) {
            currentContext.user = __assign(__assign({}, ((0, primeobjects_helper_util_1.isObject)(currentContext.user) ? currentContext.user : {})), settingContext.user);
        }
        if ((0, primeobjects_helper_util_1.isObject)(settingContext.solution)) {
            currentContext.solution = __assign(__assign({}, ((0, primeobjects_helper_util_1.isObject)(currentContext.solution)
                ? currentContext.solution
                : {})), settingContext.solution);
        }
        setContext(currentContext);
        if ((0, lodash_1.isFunction)(settings === null || settings === void 0 ? void 0 : settings.onSuccess)) {
            settings === null || settings === void 0 ? void 0 : settings.onSuccess(currentContext);
        }
        return currentContext;
    };
    var getCurrentContext = function (key) {
        var newSettings = (0, lodash_1.cloneDeep)(settings
            ? settings
            : {
                signInUrl: "/auth/sign-in",
                needAuthorization: true,
                onSuccess: null,
                onError: null
            });
        if (!(0, lodash_1.isBoolean)(newSettings.needAuthorization)) {
            newSettings.needAuthorization = true;
        }
        if (!(0, lodash_1.isBoolean)(newSettings.needSolution)) {
            newSettings.needSolution = true;
        }
        var apiParams = {
            needAuthorization: newSettings.needAuthorization == true,
            skipAuthentication: newSettings.skipAuthentication == true,
            needSolution: newSettings.needSolution == true
        };
        if ((0, primeobjects_helper_util_1.isNonEmptyString)(newSettings.recordId))
            apiParams.recordId = newSettings.recordId;
        if ((0, primeobjects_helper_util_1.isNonEmptyString)(newSettings.recordIdByMembership))
            apiParams.recordIdByMembership = newSettings.recordIdByMembership;
        if ((0, primeobjects_helper_util_1.isNonEmptyString)(newSettings.needRecord))
            apiParams.needRecord = newSettings.needRecord;
        if ((0, primeobjects_helper_util_1.isNonEmptyString)(newSettings.needRecordByMembership))
            apiParams.needRecordByMembership =
                newSettings.needRecordByMembership;
        var cacheKey = "currentContext-".concat(key, "-").concat(apiParams.recordId, "-").concat(apiParams.recordIdByMembership, "-").concat(apiParams.skipAuthentication, "-").concat(apiParams.needAuthorization, "-").concat(apiParams.needRecord, "-").concat(apiParams.needRecordByMembership, "-").concat(apiParams.needSolution, "-").concat(refresh);
        var cacheResult = (0, primeobjects_helper_util_1.getCache)(cacheKey);
        if (cacheResult) {
            processResult(cacheResult, newSettings);
        }
        else {
            if (loading.current != cacheKey) {
                loading.current = cacheKey;
                (0, auth_call_api_1.callApi)(solution, newSettings.apiUrl
                    ? newSettings.apiUrl
                    : (0, util_1.getApiEndpoint)(solution, "solution", "current-context"), apiParams, "GET")
                    .then(function (result) {
                    (0, primeobjects_helper_util_1.setCache)(cacheKey, result);
                    if ((0, core_1.libTrackIsOn)()) {
                        console.log({
                            currentContext: cacheKey,
                            componentName: settings === null || settings === void 0 ? void 0 : settings.componentName
                        });
                    }
                    contextStore.setData(processResult(result, newSettings));
                })
                    .catch(function (error) {
                    onError(error);
                })
                    .finally(function () {
                    loading.current = "";
                });
            }
        }
    };
    (0, react_1.useEffect)(function () {
        if (!context && !SSR && solution.id) {
            (0, auth_cognito_1.getCurrentPoolUser)(solution).then(function (result) {
                if (result) {
                    getCurrentContext("".concat(solution.id, ".").concat(result.username));
                }
                else {
                    onError("getCurrentPoolUser");
                }
            });
        }
    }, [SSR, refresh, solution.id]);
    return context ? context : {};
};
exports.useCurrentContext = useCurrentContext;
//# sourceMappingURL=use-current-context.js.map