//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React, { useEffect, useState } from "react";
import { SVG, Lottie } from "primeobjects-ui-web-basic";
import { getPrimaryColor } from "primeobjects-helper-ui/build/cjs/hooks/primary-color";
import { formatNumberBMK } from "primeobjects-helper-util/build/cjs/core";
import { COLORS } from "primeobjects-helper-util/build/cjs/colors";
import { callApi } from "../context/auth-call-api";
import { getApiEndpoint } from "../util";
import { numberWithCommas } from "primeobjects-helper-util/build/cjs/core";
import { useEvent } from "primeobjects-ui-web-basic/build/cjs/hooks/use-event";
import Tooltip from "../controls/antd/tooltip";
export var Credits = function (props) {
    var _a;
    var solution = props.solution, name = props.name, dollarAreaClassName = props.dollarAreaClassName, wrapperClassName = props.wrapperClassName, creditsAreaClassName = props.creditsAreaClassName;
    var _b = useState(-10000), value = _b[0], setValue = _b[1];
    var _c = useState(false), error = _c[0], setError = _c[1];
    var label = (_a = props.label) !== null && _a !== void 0 ? _a : "Credits";
    var primaryColor = getPrimaryColor(solution);
    var refreshCredits = useEvent("ai-credit-update-channel")[0];
    var dollarUSD = Math.ceil(value * 0.00001 * 100) / 100;
    var getColor = function (v) {
        if (v == -10000)
            return COLORS.GRAY[600];
        if (v > 20000)
            return COLORS.GREEN["600"];
        if (v > 5000)
            return COLORS.LIME["600"];
        if (v > 500)
            return COLORS.ORANGE["600"];
        return COLORS.RED["600"];
    };
    var color = getColor(value);
    useEffect(function () {
        callApi(solution, getApiEndpoint(solution, "organization", "retrieve-credits"), { name: name }, "GET")
            .then(function (result) {
            setValue(result.balance);
        })
            .catch(function (err) {
            console.error(err);
            setError(true);
        });
    }, [refreshCredits]);
    var renderError = function () {
        if (!error)
            return null;
        return (React.createElement(React.Fragment, null,
            React.createElement(SVG, { src: "/icons/platform/wallet.svg", size: 20, className: "mr-2" }),
            React.createElement("div", { className: "text-red-600" }, "Error")));
    };
    var renderLoader = function () {
        if (value != -10000 || error)
            return null;
        return (React.createElement(Lottie, { style: { width: 60, height: 30 }, url: "/icons/platform/lottie/dots-2.json", colors: Array(6).fill(primaryColor["500"]) }));
    };
    var renderContent = function () {
        if (value == -10000 || error)
            return null;
        return (React.createElement("span", { className: "flex flex-row cursor-pointer items-center" },
            React.createElement("span", { className: "text-sm font-bold px-1 ".concat(creditsAreaClassName !== null && creditsAreaClassName !== void 0 ? creditsAreaClassName : ""), style: { color: color } }, formatNumberBMK(value)),
            React.createElement("span", { className: "text-xs text-gray-600 px-1 ".concat(dollarAreaClassName !== null && dollarAreaClassName !== void 0 ? dollarAreaClassName : "") }, "(USD: $".concat(numberWithCommas(dollarUSD), ")"))));
    };
    return (React.createElement("div", { className: "m-4 flex flex-row py-2 px-3".concat(wrapperClassName !== null && wrapperClassName !== void 0 ? wrapperClassName : "") }, !error ? (React.createElement(Tooltip, { title: React.createElement("span", null,
            label,
            ": ",
            numberWithCommas(value),
            React.createElement("br", null),
            "USD: $",
            numberWithCommas(dollarUSD)), color: color, placement: "bottom" },
        React.createElement("div", { className: "flex self-center items-center" },
            React.createElement(SVG, { src: "/icons/platform/wallet.svg", size: 20, className: "mr-2" }),
            renderContent(),
            renderLoader()))) : (renderError())));
};
export default Credits;
//# sourceMappingURL=credits.js.map